@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 from unittest import TestCase
 
 from xunitparser import parse
@@ -44,12 +43,16 @@ class X(object):
         assert len(list(hash(t) for t in self.ts)) == len(set(hash(t) for t in self.ts))
 
     def test_testresult(self):
-        if self.FILENAME != 'test5.xml':
+        if self.FILENAME not in ('test5.xml', 'test6.xml'):
             assert len(self.tr.failures)
         for f in self.tr.failures:
             if 'pastebin.test.PastebinTest' in repr(f[0]):
                 assert 'backend.pastebin_loggedin' in f[1]
 
+    def test_classname(self):
+        for test in self.ts:
+            assert test.classname
+
 
 class Test1(X, TestCase):
     FILENAME = 'test1.xml'
@@ -111,3 +114,7 @@ class Test5(X, TestCase):
                 assert 'PathToMyProject' in test.trace
                 found = True
         assert found
+
+
+class Test6(X, TestCase):
+    FILENAME = 'test6.xml'
